
==================
    Code
==================

In order to get a quick start with the ``tmt`` source code you
might want look through the :ref:`classes` first to learn about
the overall structure of the code. The :ref:`plugin_introduction`
can help if you are planning to write a new plugin. To find detailed
information about individual classes, modules and packages inspect
the documentation generated from sources linked below.

.. toctree::
    :maxdepth: 2

    Class Overview <classes>
    Template Extensions <template-extensions>
    Plugin Introduction <plugin-introduction>
    tmt <../z_autodocs/tmt>

.. toctree::
    :maxdepth: 3

    tmt.steps <../z_autodocs/tmt.steps>
